function empiricaldf
% In this exercise we compute the emipirical distribution function of L_2
% in a homogeneous Bernoulli mixture model

% set of parameters
mu=0.01;
sigma=0.2;
rho=0.5;
V0=100;
D=90;

%% compute theoretical cdf
% standardized face value of the debt
C= (log(D/V0)-(mu-sigma^2/2))/sigma;

% compute p(X)
jointdefault = @(x) normcdf((C-sqrt(rho)*x)/sqrt(1-rho));

% compute the theoretical pdf
integrand = @(x,i) jointdefault(x).^i.*(1-jointdefault(x)).^(2-i).*normpdf(x);
temp  = @(i) nchoosek(2,i).* integral(@(x) integrand(x,i),-Inf,Inf);


% possible values for i
grid=[0,1,2];
values=cumsum([temp(0),temp(1),temp(2)]);



%% compute empirical cdf
N= 10^4;
% simulate X
draw = randn(1,N);

% simulate Y_1 and Y_2
y1draw = binornd(1,jointdefault(draw));
y2draw = binornd(1,jointdefault(draw));
% compute L= Y_1+Y_2
Ldraw = y1draw+y2draw;

% compute the empiricial distribution function
empirical=ecdf(Ldraw);

% plot the theoretical cdf and the empirical cdf
figure(1);
stairs(grid,values,'r*-')
hold on;
stairs(grid,empirical(2:end),'g*-')
hold off;
end